@@ -1,4 +1,4 @@
-from mongoengine import QuerySet
+from mongoengine import Document, QuerySet
 from pydantic import validator
 
 from ...base.filter import BaseFilterModel
@@ -16,14 +16,14 @@ class Filter(BaseFilterModel):
             created_at: DatetimeField()
 
         class MyModelFilter(Filter):
-            id: Optional[int]
-            id__in: Optional[str]
-            count: Optional[int]
-            count__lte: Optional[int]
-            created_at__gt: Optional[datetime]
-            name__ne: Optional[str]
-            name__nin: Optional[list[str]]
-            name__isnull: Optional[bool]
+            id: int | None
+            id__in: str | None
+            count: int | None
+            count__lte: int | None
+            created_at__gt: datetime | None
+            name__ne: str | None
+            name__nin: list[str] | None
+            name__isnull: bool | None
 
     # Limitation
 
@@ -31,6 +31,10 @@ class Filter(BaseFilterModel):
     Instead, you should set a value on the instance of the filter class.
     """
 
+    class Constants:
+        collection: Document
+        prefix: str
+
     @validator("*", pre=True)
     def split_str(cls, value, field):
         if (field.name.endswith("__in") or field.name.endswith("__nin")) and isinstance(value, str):
@@ -38,10 +42,18 @@ class Filter(BaseFilterModel):
         return value
 
     def filter(self, query: QuerySet):
-        for field_name, value in self.dict(exclude_defaults=True, exclude_unset=True).items():
-            field = getattr(self, field_name)
-            if isinstance(field, Filter):
-                query = field.filter(query)
+        for field_name, value in self.dict(exclude_none=True, exclude_unset=True).items():
+            field_value = getattr(self, field_name)
+            if isinstance(field_value, Filter):
+                if not field_value.dict(exclude_none=True, exclude_unset=True):
+                    continue
+                query = query.filter(
+                    **{
+                        f"{field_value.Constants.prefix}__in": field_value.filter(
+                            field_value.Constants.collection.objects()
+                        )
+                    }
+                )
             else:
                 if field_name.endswith("__isnull"):
                     field_name = field_name.replace("__isnull", "")
